"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Button;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _reactNativeLinearGradient = _interopRequireDefault(require("react-native-linear-gradient"));

var _coalesceNonElementChildren = _interopRequireDefault(require("./coalesceNonElementChildren"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const systemButtonOpacity = 0.5;

function Button(props) {
  const touchableProps = {
    activeOpacity: _computeActiveOpacity(props)
  };
  let containerStyleByType = {};

  switch (props.type) {
    case 'primary':
      containerStyleByType = styles.btnPrimaryStyle;
      break;

    case 'minor':
      containerStyleByType = styles.btnMinorStyle;
      break;

    default:
      containerStyleByType = styles.btnPrimaryStyle;
      break;
  }

  const containerStyle = [styles.btnBaseStyle, containerStyleByType, props.containerStyle, props.disabled ? styles.defaultDisabledContainerStyle : null, props.disabled ? props.disabledContainerStyle : null];

  if (!props.disabled) {
    touchableProps.onPress = props.onPress;
    touchableProps.onPressIn = props.onPressIn;
    touchableProps.onPressOut = props.onPressOut;
    touchableProps.onLongPress = props.onLongPress;
    touchableProps.delayPressIn = props.delayPressIn;
    touchableProps.delayPressOut = props.delayPressOut;
    touchableProps.delayLongPress = props.delayLongPress;
  }

  if (_reactNative.Platform.OS === 'ios') {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, _extends({}, touchableProps, {
      testID: props.testID,
      style: containerStyle,
      accessibilityLabel: props.accessibilityLabel,
      accessibilityRole: "button"
    }), _renderGroupedChildren(props));
  } else {
    const background = props.androidBackground ? props.androidBackground : _reactNative.TouchableNativeFeedback.SelectableBackground();
    let padding = 0;

    if (containerStyle[0] && containerStyle[0].padding) {
      padding = containerStyle[0].padding;
      const fixedStyle = Object.assign({}, containerStyle[0], {
        padding: 0
      });
      containerStyle[0] = fixedStyle;
    }

    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: containerStyle
    }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableNativeFeedback, _extends({}, touchableProps, {
      style: {
        width: '100%',
        height: '100%'
      },
      testID: props.testID,
      accessibilityLabel: props.accessibilityLabel,
      accessibilityRole: "button",
      background: background
    }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        padding: padding,
        width: '100%',
        height: '100%',
        alignItems: 'center',
        justifyContent: 'center'
      }
    }, _renderGroupedChildren(props))));
  }
}

function _computeActiveOpacity(props) {
  if (props.disabled) {
    return 1;
  }

  return props.activeOpacity !== null ? props.activeOpacity : systemButtonOpacity;
}

function _renderGroupedChildren(props) {
  const {
    disabled
  } = props; // 根据按钮类型选择按钮字体样式

  let fontText = {};

  switch (props.type) {
    case 'primary':
      fontText = styles.text;
      break;

    case 'minor':
      fontText = styles.minorText;
      break;

    default:
      fontText = styles.text;
      break;
  } // 配置是否禁止按钮的样式


  const style = [fontText, disabled ? styles.disabledText : null, props.fontStyle, disabled ? props.fontDisabledStyle : null];
  const childGroupStyle = [styles.group, props.childGroupStyle];
  const children = (0, _coalesceNonElementChildren.default)(props.children, (children, index) => {
    if (props.linearGradientStyle) {
      // 配置渐变样式
      const linearStyle = [props.linearGradientStyle.style];
      const linearGradientConfig = {
        start: {
          x: 0,
          y: 0
        },
        end: {
          x: 1,
          y: 1
        },
        colors: ['#FF3B2D', '#FF5E40'],
        ...props.linearGradientStyle,
        style: linearStyle
      };
      return /*#__PURE__*/_react.default.createElement(_reactNativeLinearGradient.default, linearGradientConfig, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: index,
        style: style,
        allowFontScaling: props.allowFontScaling
      }, children));
    } else {
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: index,
        style: style,
        allowFontScaling: props.allowFontScaling
      }, children);
    }
  });

  switch (children.length) {
    case 0:
      return null;

    case 1:
      return children[0];

    default:
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: childGroupStyle
      }, children);
  }
}

const styles = _reactNative.StyleSheet.create({
  btnBaseStyle: {
    justifyContent: 'center',
    alignItems: 'center',
    width: 100,
    height: 40,
    borderRadius: 20
  },
  btnPrimaryStyle: {
    backgroundColor: '#f43'
  },
  btnMinorStyle: {
    backgroundColor: 'transparent',
    borderColor: '#ff542a',
    borderWidth: 1
  },
  minorText: {
    color: '#ff542a'
  },
  text: {
    color: '#fff',
    fontSize: 14,
    fontWeight: '500',
    textAlign: 'center'
  },
  disabledText: {
    color: '#f7c9bf'
  },
  defaultDisabledContainerStyle: {
    borderColor: '#f7c9bf'
  },
  group: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center'
  }
});
//# sourceMappingURL=Button.js.map